sqlobject.tests.test_NoneValuedResultItem module — SQLObject 3.9.1 documentation

# sqlobject.tests.test_NoneValuedResultItem module

class `sqlobject.tests.test_NoneValuedResultItem.` `SOTestComposer`(**kw)

  Bases: `sqlobject.main.SQLObject`

  `j` = so_test_composer
  property `name`
  `q` = so_test_composer
  class `sqlmeta`(instance)

    Bases: `sqlobject.main.sqlmeta`

    `childName` = None
    `idName` = 'id'
    `indexes` = []
    `joinDefinitions` = []
    `joins` = []
    `soClass`

      alias of `sqlobject.tests.test_NoneValuedResultItem.SOTestComposer`

    `style` = <sqlobject.styles.MixedCaseUnderscoreStyle object>
    `table` = 'so_test_composer'

class `sqlobject.tests.test_NoneValuedResultItem.` `SOTestWork`(**kw)

  Bases: `sqlobject.main.SQLObject`

  property `composer`
  property `composerID`
  `j` = so_test_work
  `q` = so_test_work
  class `sqlmeta`(instance)

    Bases: `sqlobject.main.sqlmeta`

    `childName` = None
    `idName` = 'work_id'
    `indexes` = []
    `joinDefinitions` = []
    `joins` = []
    `soClass`

      alias of `sqlobject.tests.test_NoneValuedResultItem.SOTestWork`

    `style` = <sqlobject.styles.MixedCaseUnderscoreStyle object>
    `table` = 'so_test_work'
  property `title`

`sqlobject.tests.test_NoneValuedResultItem.` `test1`()